package com.bwie.auth.service;


import com.alibaba.fastjson.JSON;
import com.bwie.auth.feign.UserFeignService;
import com.bwie.common.constants.JwtConstants;
import com.bwie.common.constants.TokenConstants;
import com.bwie.common.pojo.DTO.DTOUser;
import com.bwie.common.pojo.User;
import com.bwie.common.pojo.VO.VOUser;
import com.bwie.common.result.Result;
import com.bwie.common.utils.JwtUtils;
import org.apache.commons.lang.RandomStringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.Random;
import java.util.UUID;
import java.util.concurrent.TimeUnit;

/**
 * @author 86175
 */
@Service
public class AuthServiceImpl implements AuthService{

    @Autowired
    private UserFeignService userFeignService;
    @Autowired
    private StringRedisTemplate redisTemplate;

    /**
     * 发送手机号
     * @param phone
     * @return
     */
    @Override
    public Result sendCode(String phone) {

        Result<User> byPhone = userFeignService.findByPhone(phone);
        User user = byPhone.getData();
        if (user==null){
            return Result.error("手机号不存在,请先注册");
        }
        String code="";
        for (int i = 0; i < 4; i++) {
            code+=new Random().nextInt(10);
        }
        redisTemplate.opsForValue().set(phone,code,20, TimeUnit.MINUTES);

        return Result.success(code,"发送成功");
    }

    /**
     * 登录验证
     * @param voUser
     * @return
     */
    @Override
    public Result<DTOUser> users(VOUser voUser) {
        Result<User> byPhone = userFeignService.findByPhone(voUser.getPhone());
        User user = byPhone.getData();
        /**
         * 判断手机号是否存在，存在则继续，不存在则返回一个信息
         */
        if (user==null){
            return Result.error("手机号不存在,请先注册");
        }
        /**
         * 验证码验证
         */
        String code = redisTemplate.opsForValue().get(voUser.getPhone());
        if (!voUser.getCode().equals(code)){
            return Result.error("密码错误");
        }

        HashMap<String, Object> map = new HashMap<>();
        /**
         * 随机生成一个钥匙
         */
        String userKey = UUID.randomUUID().toString();
        map.put(JwtConstants.USER_KEY,userKey);
        /**
         * 生成令牌
         */
        String token = JwtUtils.createToken(map);
        /**
         * 将user数据存入redis中
         */
        redisTemplate.opsForValue().set(TokenConstants.LOGIN_TOKEN_KEY+userKey, JSON.toJSONString(user),59,TimeUnit.MINUTES);
        /**
         * 往响应的对象赋值
         */
        DTOUser dtoUser = new DTOUser();
        dtoUser.setToken(token);
        dtoUser.setExpiredTime("存储时长为59分钟");
        if (1==user.userRole){
            return Result.success(dtoUser,"登录成功");
        }
        return Result.success(dtoUser,"欢迎"+user.userName+"登录");
    }

    /**
     * 注册
     * @param user
     * @return
     */
    @Override
    public Result regUser(User user) {

        Result<Integer> result = userFeignService.regLogin(user);
        Integer data = result.getData();

        return Result.success(data>0?"添加成功":"添加失败");
    }
}
