package com.bwie.buy.service.impl;

import com.alibaba.fastjson.JSON;
import com.bwie.buy.dao.BuyDao;
import com.bwie.buy.service.BuyService;
import com.bwie.common.constants.JwtConstants;
import com.bwie.common.pojo.DTO.DTOGoods;
import com.bwie.common.pojo.DTO.DTOUser;
import com.bwie.common.pojo.Sell;
import com.bwie.common.pojo.Shop;
import com.bwie.common.pojo.VO.VOGoods;
import com.bwie.common.result.Result;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * @author FangShiBa
 * @date 2023/12/17
 * @apiNote
 */
@Service
public class BuyServiceImp implements BuyService {
    @Autowired
    private BuyDao dao;
    @Autowired
    private RedisTemplate<String,String> redisTemplate;
    @Autowired
    private HttpServletRequest request;

    @Override
    public Result buyGood(VOGoods voGoods) {
        if(null==voGoods.getFacilityId()||null==voGoods.getPayForMoney()){
            return Result.error("输入的值有误或未输入");
        }
        Shop shop=dao.findById(voGoods.getShopId());
        if(shop.getShopPrice()>voGoods.getPayForMoney()){
            return Result.error("小老弟,钱不够");
        }

        //voGoods 参数有商品编号和售货机编号
        dao.buyGood(voGoods);
        String token = request.getHeader("token");
        String s = redisTemplate.opsForValue().get(JwtConstants.LOGIN_TOKEN + token);
        DTOUser dtoUser = JSON.parseObject(s, DTOUser.class);
        Sell sell = new Sell();
        sell.setFacilityId(voGoods.getFacilityId());
        sell.setShopId(voGoods.getShopId());
        sell.setUserId(dtoUser.getUserId());
        dao.addSell(sell);

        return Result.success("购买成功");
    }

    @Override
    public Result showGoodsList(VOGoods voGoods) {
        PageHelper.startPage(voGoods.getPageNum(),voGoods.getPageSize());
        List<DTOGoods> list=dao.showGoodsList(voGoods);
        PageInfo<DTOGoods> info = new PageInfo<>(list);
        return Result.success(info);
    }
}
